==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/AssigningCategoryStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata";
import { AssigningCategoryStyleEventArgsDescription } from "./AssigningCategoryStyleEventArgsDescription";
/**
 * @hidden
 */
export let AssigningCategoryStyleEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningCategoryStyleEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningCategoryStyleEventArgsDescriptionMetadata.a == null) {
                AssigningCategoryStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningCategoryStyleEventArgsDescriptionMetadata.c(AssigningCategoryStyleEventArgsDescriptionMetadata.a);
            }
            if (a.k(AssigningCategoryStyleEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(AssigningCategoryStyleEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningCategoryStyleEventArgsDescriptionMetadata.b(a);
            a.ac("AssigningCategoryStyleEventArgs", () => new AssigningCategoryStyleEventArgsDescription());
            a.ab("AssigningCategoryStyleEventArgs", AssigningCategoryStyleEventArgsDescriptionMetadata.a);
        }
    }
    AssigningCategoryStyleEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(AssigningCategoryStyleEventArgsDescriptionMetadata, 'AssigningCategoryStyleEventArgsDescriptionMetadata');
    AssigningCategoryStyleEventArgsDescriptionMetadata.a = null;
    return AssigningCategoryStyleEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/AssigningCategoryStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata";
import { AssigningCategoryStyleEventArgsDescription } from "./AssigningCategoryStyleEventArgsDescription";
/**
 * @hidden
 */
export let AssigningCategoryStyleEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningCategoryStyleEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningCategoryStyleEventArgsDescriptionMetadata.a == null) {
                AssigningCategoryStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningCategoryStyleEventArgsDescriptionMetadata.c(AssigningCategoryStyleEventArgsDescriptionMetadata.a);
            }
            if (a.k(AssigningCategoryStyleEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(AssigningCategoryStyleEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningCategoryStyleEventArgsDescriptionMetadata.b(a);
            a.ae("AssigningCategoryStyleEventArgs", () => new AssigningCategoryStyleEventArgsDescription());
            a.ad("AssigningCategoryStyleEventArgs", AssigningCategoryStyleEventArgsDescriptionMetadata.a);
        }
    }
    AssigningCategoryStyleEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(AssigningCategoryStyleEventArgsDescriptionMetadata, 'AssigningCategoryStyleEventArgsDescriptionMetadata');
    AssigningCategoryStyleEventArgsDescriptionMetadata.a = null;
    return AssigningCategoryStyleEventArgsDescriptionMetadata;
})();
